Welcome to DemoPackage! — DemoPackage 0.0.1 documentation

### Navigation

- index
- modules |
- next |
- DemoPackage 0.0.1 documentation »

# Welcome to DemoPackage!

DemoPackage as the name suggests is just a sample package aka tutorial to cover all the aspects of creating a python package. This package can be used as a base for development of other python libraries on top of it.

With DemoPackage I have covered the basics of:

1. Version control using git on Github.
2. Python Package creation and maintenance at PyPi.
3. Python package installation using Setuptools.
4. Automatic Documentation using Sphinx.
5. Hosting the documentation using Github-pages and Readthedocs.org

I’ll be updating the detailed instructions as soon as possible.

## Table of Contents:

- DemoPackage Package
  - `DemoPackage` Package
    - DemoPackage
  - `utils` Module
  - Subpackages
    - tests Package
      - `test_utils` Module

# Indices and tables

- Index
- Module Index
- Search Page

# License Information

Author Details:
  - Author - Sourabh Bajaj.
  - Email - sourabhbajaj@gatech.edu.
  - License - BSD License.

### Navigation

- index
- modules |
- next |
- DemoPackage 0.0.1 documentation »